"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.password_vaults_api import PasswordVaultsApi  # noqa: E501


class TestPasswordVaultsApi(unittest.TestCase):
    """PasswordVaultsApi unit test stubs"""

    def setUp(self):
        self.api = PasswordVaultsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_password_vault_by_id(self):
        """Test case for get_password_vault_by_id

        Get a password vault by ID or Name.  # noqa: E501
        """
        pass

    def test_get_password_vaults(self):
        """Test case for get_password_vaults

        List all password vaults.  # noqa: E501
        """
        pass

    def test_search_password_vaults(self):
        """Test case for search_password_vaults

        Search for Password Vaults.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
