"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
)
from ..model_utils import OpenApiModel
from delphix.api.gateway.exceptions import ApiAttributeError


def lazy_import():
    from delphix.api.gateway.model.dct_product_telemetry_bundle_administration_info import DCTProductTelemetryBundleAdministrationInfo
    from delphix.api.gateway.model.dct_product_telemetry_bundle_api_telemetry import DctProductTelemetryBundleApiTelemetry
    from delphix.api.gateway.model.dct_product_telemetry_bundle_compliance_job import DctProductTelemetryBundleComplianceJob
    from delphix.api.gateway.model.dct_product_telemetry_bundle_compliance_node import DctProductTelemetryBundleComplianceNode
    from delphix.api.gateway.model.dct_product_telemetry_bundle_compliance_object_counts import DctProductTelemetryBundleComplianceObjectCounts
    from delphix.api.gateway.model.dct_product_telemetry_bundle_connector import DctProductTelemetryBundleConnector
    from delphix.api.gateway.model.dct_product_telemetry_bundle_continuous_data_engine_storage import DctProductTelemetryBundleContinuousDataEngineStorage
    from delphix.api.gateway.model.dct_product_telemetry_bundle_d_source_info import DCTProductTelemetryBundleDSourceInfo
    from delphix.api.gateway.model.dct_product_telemetry_bundle_data_connection_storage import DctProductTelemetryBundleDataConnectionStorage
    from delphix.api.gateway.model.dct_product_telemetry_bundle_environment_info import DCTProductTelemetryBundleEnvironmentInfo
    from delphix.api.gateway.model.dct_product_telemetry_bundle_execution import DctProductTelemetryBundleExecution
    from delphix.api.gateway.model.dct_product_telemetry_bundle_hyperscale_orchestrator import DctProductTelemetryBundleHyperscaleOrchestrator
    from delphix.api.gateway.model.dct_product_telemetry_bundle_job_orchestrator import DctProductTelemetryBundleJobOrchestrator
    from delphix.api.gateway.model.dct_product_telemetry_bundle_license_info import DctProductTelemetryBundleLicenseInfo
    from delphix.api.gateway.model.dct_product_telemetry_bundle_object_counts import DCTProductTelemetryBundleObjectCounts
    from delphix.api.gateway.model.dct_product_telemetry_bundle_product_info import DctProductTelemetryBundleProductInfo
    from delphix.api.gateway.model.dct_product_telemetry_bundle_registered_engine import DctProductTelemetryBundleRegisteredEngine
    from delphix.api.gateway.model.dct_product_telemetry_bundle_rule_set import DctProductTelemetryBundleRuleSet
    from delphix.api.gateway.model.dct_product_telemetry_bundle_vdb_info import DCTProductTelemetryBundleVDBInfo
    from delphix.api.gateway.model.dct_product_telemetry_data_connection import DctProductTelemetryDataConnection
    globals()['DCTProductTelemetryBundleAdministrationInfo'] = DCTProductTelemetryBundleAdministrationInfo
    globals()['DCTProductTelemetryBundleDSourceInfo'] = DCTProductTelemetryBundleDSourceInfo
    globals()['DCTProductTelemetryBundleEnvironmentInfo'] = DCTProductTelemetryBundleEnvironmentInfo
    globals()['DCTProductTelemetryBundleObjectCounts'] = DCTProductTelemetryBundleObjectCounts
    globals()['DCTProductTelemetryBundleVDBInfo'] = DCTProductTelemetryBundleVDBInfo
    globals()['DctProductTelemetryBundleApiTelemetry'] = DctProductTelemetryBundleApiTelemetry
    globals()['DctProductTelemetryBundleComplianceJob'] = DctProductTelemetryBundleComplianceJob
    globals()['DctProductTelemetryBundleComplianceNode'] = DctProductTelemetryBundleComplianceNode
    globals()['DctProductTelemetryBundleComplianceObjectCounts'] = DctProductTelemetryBundleComplianceObjectCounts
    globals()['DctProductTelemetryBundleConnector'] = DctProductTelemetryBundleConnector
    globals()['DctProductTelemetryBundleContinuousDataEngineStorage'] = DctProductTelemetryBundleContinuousDataEngineStorage
    globals()['DctProductTelemetryBundleDataConnectionStorage'] = DctProductTelemetryBundleDataConnectionStorage
    globals()['DctProductTelemetryBundleExecution'] = DctProductTelemetryBundleExecution
    globals()['DctProductTelemetryBundleHyperscaleOrchestrator'] = DctProductTelemetryBundleHyperscaleOrchestrator
    globals()['DctProductTelemetryBundleJobOrchestrator'] = DctProductTelemetryBundleJobOrchestrator
    globals()['DctProductTelemetryBundleLicenseInfo'] = DctProductTelemetryBundleLicenseInfo
    globals()['DctProductTelemetryBundleProductInfo'] = DctProductTelemetryBundleProductInfo
    globals()['DctProductTelemetryBundleRegisteredEngine'] = DctProductTelemetryBundleRegisteredEngine
    globals()['DctProductTelemetryBundleRuleSet'] = DctProductTelemetryBundleRuleSet
    globals()['DctProductTelemetryDataConnection'] = DctProductTelemetryDataConnection


class DctProductTelemetryBundle(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
    }

    validations = {
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'product_info': (DctProductTelemetryBundleProductInfo,),  # noqa: E501
            'registered_engines': ([DctProductTelemetryBundleRegisteredEngine],),  # noqa: E501
            'api_telemetry': ([DctProductTelemetryBundleApiTelemetry],),  # noqa: E501
            'dates': ([date],),  # noqa: E501
            'bundle_generation_time': (datetime,),  # noqa: E501
            'license': (DctProductTelemetryBundleLicenseInfo,),  # noqa: E501
            'object_counts': (DCTProductTelemetryBundleObjectCounts,),  # noqa: E501
            'administration': (DCTProductTelemetryBundleAdministrationInfo,),  # noqa: E501
            'vdbs': ([DCTProductTelemetryBundleVDBInfo],),  # noqa: E501
            'dsources': ([DCTProductTelemetryBundleDSourceInfo],),  # noqa: E501
            'environments': ([DCTProductTelemetryBundleEnvironmentInfo],),  # noqa: E501
            'continuous_data_engine_storage': ([DctProductTelemetryBundleContinuousDataEngineStorage],),  # noqa: E501
            'data_connections': ([DctProductTelemetryDataConnection],),  # noqa: E501
            'data_connections_storage': ([DctProductTelemetryBundleDataConnectionStorage],),  # noqa: E501
            'connectors': ([DctProductTelemetryBundleConnector],),  # noqa: E501
            'rule_sets': ([DctProductTelemetryBundleRuleSet],),  # noqa: E501
            'executions': ([DctProductTelemetryBundleExecution],),  # noqa: E501
            'compliance_jobs': ([DctProductTelemetryBundleComplianceJob],),  # noqa: E501
            'job_orchestrators': ([DctProductTelemetryBundleJobOrchestrator],),  # noqa: E501
            'compliance_nodes': ([DctProductTelemetryBundleComplianceNode],),  # noqa: E501
            'hyperscale_orchestrators': ([DctProductTelemetryBundleHyperscaleOrchestrator],),  # noqa: E501
            'compliance_object_counts': (DctProductTelemetryBundleComplianceObjectCounts,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'product_info': 'product_info',  # noqa: E501
        'registered_engines': 'registered_engines',  # noqa: E501
        'api_telemetry': 'api_telemetry',  # noqa: E501
        'dates': 'dates',  # noqa: E501
        'bundle_generation_time': 'bundle_generation_time',  # noqa: E501
        'license': 'license',  # noqa: E501
        'object_counts': 'object_counts',  # noqa: E501
        'administration': 'administration',  # noqa: E501
        'vdbs': 'vdbs',  # noqa: E501
        'dsources': 'dsources',  # noqa: E501
        'environments': 'environments',  # noqa: E501
        'continuous_data_engine_storage': 'continuous_data_engine_storage',  # noqa: E501
        'data_connections': 'data_connections',  # noqa: E501
        'data_connections_storage': 'data_connections_storage',  # noqa: E501
        'connectors': 'connectors',  # noqa: E501
        'rule_sets': 'rule_sets',  # noqa: E501
        'executions': 'executions',  # noqa: E501
        'compliance_jobs': 'compliance_jobs',  # noqa: E501
        'job_orchestrators': 'job_orchestrators',  # noqa: E501
        'compliance_nodes': 'compliance_nodes',  # noqa: E501
        'hyperscale_orchestrators': 'hyperscale_orchestrators',  # noqa: E501
        'compliance_object_counts': 'compliance_object_counts',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, product_info, registered_engines, api_telemetry, dates, bundle_generation_time, license, *args, **kwargs):  # noqa: E501
        """DctProductTelemetryBundle - a model defined in OpenAPI

        Args:
            product_info (DctProductTelemetryBundleProductInfo):
            registered_engines ([DctProductTelemetryBundleRegisteredEngine]): A list of Delphix Engines registered with this instance of Data Control Tower.
            api_telemetry ([DctProductTelemetryBundleApiTelemetry]): A list of API telemetry records.\"
            dates ([date]): A list of dates for which telemetry data is included in this bundle.
            bundle_generation_time (datetime): The UTC time at bundle generation (ISO 8601 format).
            license (DctProductTelemetryBundleLicenseInfo):

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            object_counts (DCTProductTelemetryBundleObjectCounts): [optional]  # noqa: E501
            administration (DCTProductTelemetryBundleAdministrationInfo): [optional]  # noqa: E501
            vdbs ([DCTProductTelemetryBundleVDBInfo]): List of vdbs.. [optional]  # noqa: E501
            dsources ([DCTProductTelemetryBundleDSourceInfo]): The Delphix storage-based copy of the source database including its history.. [optional]  # noqa: E501
            environments ([DCTProductTelemetryBundleEnvironmentInfo]): A grouping of a single host or a cluster of hosts.. [optional]  # noqa: E501
            continuous_data_engine_storage ([DctProductTelemetryBundleContinuousDataEngineStorage]): The time series data for continuous data engine storage usage.. [optional]  # noqa: E501
            data_connections ([DctProductTelemetryDataConnection]): A list of data connections registered with this instance of Data Control Tower.. [optional]  # noqa: E501
            data_connections_storage ([DctProductTelemetryBundleDataConnectionStorage]): The time series data for data connection storage usage.. [optional]  # noqa: E501
            connectors ([DctProductTelemetryBundleConnector]): A list of connectors registered with this instance of Data Control Tower.. [optional]  # noqa: E501
            rule_sets ([DctProductTelemetryBundleRuleSet]): A list of rule sets registered with this instance of Data Control Tower.. [optional]  # noqa: E501
            executions ([DctProductTelemetryBundleExecution]): A list of masking executions registered with this instance of Data Control Tower.. [optional]  # noqa: E501
            compliance_jobs ([DctProductTelemetryBundleComplianceJob]): A list of compliance jobs registered with this instance of Data Control Tower.. [optional]  # noqa: E501
            job_orchestrators ([DctProductTelemetryBundleJobOrchestrator]): A list of job orchestrators registered with this instance of Data Control Tower.. [optional]  # noqa: E501
            compliance_nodes ([DctProductTelemetryBundleComplianceNode]): A list of compliance nodes registered with this instance of Data Control Tower.. [optional]  # noqa: E501
            hyperscale_orchestrators ([DctProductTelemetryBundleHyperscaleOrchestrator]): A list of hyperscale orchestrators registered with this instance of Data Control Tower.. [optional]  # noqa: E501
            compliance_object_counts (DctProductTelemetryBundleComplianceObjectCounts): [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.product_info = product_info
        self.registered_engines = registered_engines
        self.api_telemetry = api_telemetry
        self.dates = dates
        self.bundle_generation_time = bundle_generation_time
        self.license = license
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, product_info, registered_engines, api_telemetry, dates, bundle_generation_time, license, *args, **kwargs):  # noqa: E501
        """DctProductTelemetryBundle - a model defined in OpenAPI

        Args:
            product_info (DctProductTelemetryBundleProductInfo):
            registered_engines ([DctProductTelemetryBundleRegisteredEngine]): A list of Delphix Engines registered with this instance of Data Control Tower.
            api_telemetry ([DctProductTelemetryBundleApiTelemetry]): A list of API telemetry records.\"
            dates ([date]): A list of dates for which telemetry data is included in this bundle.
            bundle_generation_time (datetime): The UTC time at bundle generation (ISO 8601 format).
            license (DctProductTelemetryBundleLicenseInfo):

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            object_counts (DCTProductTelemetryBundleObjectCounts): [optional]  # noqa: E501
            administration (DCTProductTelemetryBundleAdministrationInfo): [optional]  # noqa: E501
            vdbs ([DCTProductTelemetryBundleVDBInfo]): List of vdbs.. [optional]  # noqa: E501
            dsources ([DCTProductTelemetryBundleDSourceInfo]): The Delphix storage-based copy of the source database including its history.. [optional]  # noqa: E501
            environments ([DCTProductTelemetryBundleEnvironmentInfo]): A grouping of a single host or a cluster of hosts.. [optional]  # noqa: E501
            continuous_data_engine_storage ([DctProductTelemetryBundleContinuousDataEngineStorage]): The time series data for continuous data engine storage usage.. [optional]  # noqa: E501
            data_connections ([DctProductTelemetryDataConnection]): A list of data connections registered with this instance of Data Control Tower.. [optional]  # noqa: E501
            data_connections_storage ([DctProductTelemetryBundleDataConnectionStorage]): The time series data for data connection storage usage.. [optional]  # noqa: E501
            connectors ([DctProductTelemetryBundleConnector]): A list of connectors registered with this instance of Data Control Tower.. [optional]  # noqa: E501
            rule_sets ([DctProductTelemetryBundleRuleSet]): A list of rule sets registered with this instance of Data Control Tower.. [optional]  # noqa: E501
            executions ([DctProductTelemetryBundleExecution]): A list of masking executions registered with this instance of Data Control Tower.. [optional]  # noqa: E501
            compliance_jobs ([DctProductTelemetryBundleComplianceJob]): A list of compliance jobs registered with this instance of Data Control Tower.. [optional]  # noqa: E501
            job_orchestrators ([DctProductTelemetryBundleJobOrchestrator]): A list of job orchestrators registered with this instance of Data Control Tower.. [optional]  # noqa: E501
            compliance_nodes ([DctProductTelemetryBundleComplianceNode]): A list of compliance nodes registered with this instance of Data Control Tower.. [optional]  # noqa: E501
            hyperscale_orchestrators ([DctProductTelemetryBundleHyperscaleOrchestrator]): A list of hyperscale orchestrators registered with this instance of Data Control Tower.. [optional]  # noqa: E501
            compliance_object_counts (DctProductTelemetryBundleComplianceObjectCounts): [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.product_info = product_info
        self.registered_engines = registered_engines
        self.api_telemetry = api_telemetry
        self.dates = dates
        self.bundle_generation_time = bundle_generation_time
        self.license = license
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")
