"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.data_classes_api import DataClassesApi  # noqa: E501


class TestDataClassesApi(unittest.TestCase):
    """DataClassesApi unit test stubs"""

    def setUp(self):
        self.api = DataClassesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_data_class_algorithms(self):
        """Test case for add_data_class_algorithms

        Add algorithms to a Data Class.  # noqa: E501
        """
        pass

    def test_create_data_class(self):
        """Test case for create_data_class

        Create a Data Class.  # noqa: E501
        """
        pass

    def test_create_data_class_tags(self):
        """Test case for create_data_class_tags

        Create tags for a Data Class.  # noqa: E501
        """
        pass

    def test_delete_data_class(self):
        """Test case for delete_data_class

        Delete a Data Class.  # noqa: E501
        """
        pass

    def test_delete_data_class_tags(self):
        """Test case for delete_data_class_tags

        Delete tags for a Data Class.  # noqa: E501
        """
        pass

    def test_get_data_class_algorithms(self):
        """Test case for get_data_class_algorithms

        Retrieve the list of algorithms for a Data Class.  # noqa: E501
        """
        pass

    def test_get_data_class_by_id(self):
        """Test case for get_data_class_by_id

        Get a Data Class by ID.  # noqa: E501
        """
        pass

    def test_get_data_class_tags(self):
        """Test case for get_data_class_tags

        Get tags for a Data Class.  # noqa: E501
        """
        pass

    def test_get_data_classes(self):
        """Test case for get_data_classes

        Retrieve the list of Data Classes.  # noqa: E501
        """
        pass

    def test_remove_data_class_algorithms(self):
        """Test case for remove_data_class_algorithms

        Remove algorithms from a Data Class.  # noqa: E501
        """
        pass

    def test_search_data_class_algorithms(self):
        """Test case for search_data_class_algorithms

        Search for algorithms of a Data Class.  # noqa: E501
        """
        pass

    def test_search_data_classes(self):
        """Test case for search_data_classes

        Search for Data Classes.  # noqa: E501
        """
        pass

    def test_update_data_class(self):
        """Test case for update_data_class

        Update a Data Class.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
