"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.tags_api import TagsApi  # noqa: E501


class TestTagsApi(unittest.TestCase):
    """TagsApi unit test stubs"""

    def setUp(self):
        self.api = TagsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_tag(self):
        """Test case for get_tag

        Get a global tag by id  # noqa: E501
        """
        pass

    def test_get_tag_permissions(self):
        """Test case for get_tag_permissions

        List instances of this global tag being used to scope an access group.  # noqa: E501
        """
        pass

    def test_get_tag_usages(self):
        """Test case for get_tag_usages

        List specific usages of this global tag.  # noqa: E501
        """
        pass

    def test_get_tags(self):
        """Test case for get_tags

        Returns a list of global tags  # noqa: E501
        """
        pass

    def test_search_tag_permissions(self):
        """Test case for search_tag_permissions

        Search instances of this global tag being used to scope an access group  # noqa: E501
        """
        pass

    def test_search_tag_usages(self):
        """Test case for search_tag_usages

        Search specific usages of this global tag.  # noqa: E501
        """
        pass

    def test_search_tags(self):
        """Test case for search_tags

        Search for global tags.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
