"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.base_export_transfer_strategy_parameters import BaseExportTransferStrategyParameters
from delphix.api.gateway.model.filesystem_layout_parameters import FilesystemLayoutParameters
from delphix.api.gateway.model.in_place_export_parameters_all_of import InPlaceExportParametersAllOf
globals()['BaseExportTransferStrategyParameters'] = BaseExportTransferStrategyParameters
globals()['FilesystemLayoutParameters'] = FilesystemLayoutParameters
globals()['InPlaceExportParametersAllOf'] = InPlaceExportParametersAllOf
from delphix.api.gateway.model.in_place_export_parameters import InPlaceExportParameters


class TestInPlaceExportParameters(unittest.TestCase):
    """InPlaceExportParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInPlaceExportParameters(self):
        """Test InPlaceExportParameters"""
        # FIXME: construct object with mandatory attributes with example values
        # model = InPlaceExportParameters()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
