"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.nfs_version_reason_enum import NfsVersionReasonEnum
from delphix.api.gateway.model.oracle_custom_env_var import OracleCustomEnvVar
from delphix.api.gateway.model.oracle_service import OracleService
from delphix.api.gateway.model.oracle_tde_keystore_config_type_enum import OracleTdeKeystoreConfigTypeEnum
from delphix.api.gateway.model.tag import Tag
globals()['NfsVersionReasonEnum'] = NfsVersionReasonEnum
globals()['OracleCustomEnvVar'] = OracleCustomEnvVar
globals()['OracleService'] = OracleService
globals()['OracleTdeKeystoreConfigTypeEnum'] = OracleTdeKeystoreConfigTypeEnum
globals()['Tag'] = Tag
from delphix.api.gateway.model.staging_cdb import StagingCdb


class TestStagingCdb(unittest.TestCase):
    """StagingCdb unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStagingCdb(self):
        """Test StagingCdb"""
        # FIXME: construct object with mandatory attributes with example values
        # model = StagingCdb()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
