"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.job_orchestrators_api import JobOrchestratorsApi  # noqa: E501


class TestJobOrchestratorsApi(unittest.TestCase):
    """JobOrchestratorsApi unit test stubs"""

    def setUp(self):
        self.api = JobOrchestratorsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_job_orchestrator(self):
        """Test case for create_job_orchestrator

        Create a job orchestrator.  # noqa: E501
        """
        pass

    def test_create_job_orchestrator_tags(self):
        """Test case for create_job_orchestrator_tags

        Create tags for a job orchestrator.  # noqa: E501
        """
        pass

    def test_delete_job_orchestrator(self):
        """Test case for delete_job_orchestrator

        Delete a job orchestrator.  # noqa: E501
        """
        pass

    def test_delete_job_orchestrator_tags(self):
        """Test case for delete_job_orchestrator_tags

        Delete tags for a job orchestrator.  # noqa: E501
        """
        pass

    def test_get_job_orchestrator_application_settings(self):
        """Test case for get_job_orchestrator_application_settings

        Returns a job orchestrator's application settings.  # noqa: E501
        """
        pass

    def test_get_job_orchestrator_by_id(self):
        """Test case for get_job_orchestrator_by_id

        Retrieve a job orchestrator by ID.  # noqa: E501
        """
        pass

    def test_get_job_orchestrator_queued_operations(self):
        """Test case for get_job_orchestrator_queued_operations

        Returns a job orchestrator's queued operations.  # noqa: E501
        """
        pass

    def test_get_job_orchestrator_tags(self):
        """Test case for get_job_orchestrator_tags

        Get tags for a job orchestrator.  # noqa: E501
        """
        pass

    def test_get_job_orchestrators(self):
        """Test case for get_job_orchestrators

        Retrieve the list of job orchestrators.  # noqa: E501
        """
        pass

    def test_search_job_orchestrator_application_settings(self):
        """Test case for search_job_orchestrator_application_settings

        Search a job orchestrator's application settings.  # noqa: E501
        """
        pass

    def test_search_job_orchestrator_queued_operations(self):
        """Test case for search_job_orchestrator_queued_operations

        Search a job orchestrator's queued operations.  # noqa: E501
        """
        pass

    def test_search_job_orchestrators(self):
        """Test case for search_job_orchestrators

        Search job orchestrators.  # noqa: E501
        """
        pass

    def test_update_job_orchestrator(self):
        """Test case for update_job_orchestrator

        Update a job orchestrator.  # noqa: E501
        """
        pass

    def test_update_job_orchestrator_application_setting(self):
        """Test case for update_job_orchestrator_application_setting

        Update a job orchestrator's application setting value.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
