"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.dct_product_telemetry_bundle_administration_info import DCTProductTelemetryBundleAdministrationInfo
from delphix.api.gateway.model.dct_product_telemetry_bundle_api_telemetry import DctProductTelemetryBundleApiTelemetry
from delphix.api.gateway.model.dct_product_telemetry_bundle_compliance_job import DctProductTelemetryBundleComplianceJob
from delphix.api.gateway.model.dct_product_telemetry_bundle_compliance_node import DctProductTelemetryBundleComplianceNode
from delphix.api.gateway.model.dct_product_telemetry_bundle_compliance_object_counts import DctProductTelemetryBundleComplianceObjectCounts
from delphix.api.gateway.model.dct_product_telemetry_bundle_connector import DctProductTelemetryBundleConnector
from delphix.api.gateway.model.dct_product_telemetry_bundle_continuous_data_engine_storage import DctProductTelemetryBundleContinuousDataEngineStorage
from delphix.api.gateway.model.dct_product_telemetry_bundle_d_source_info import DCTProductTelemetryBundleDSourceInfo
from delphix.api.gateway.model.dct_product_telemetry_bundle_data_connection_storage import DctProductTelemetryBundleDataConnectionStorage
from delphix.api.gateway.model.dct_product_telemetry_bundle_environment_info import DCTProductTelemetryBundleEnvironmentInfo
from delphix.api.gateway.model.dct_product_telemetry_bundle_execution import DctProductTelemetryBundleExecution
from delphix.api.gateway.model.dct_product_telemetry_bundle_hyperscale_orchestrator import DctProductTelemetryBundleHyperscaleOrchestrator
from delphix.api.gateway.model.dct_product_telemetry_bundle_job_orchestrator import DctProductTelemetryBundleJobOrchestrator
from delphix.api.gateway.model.dct_product_telemetry_bundle_license_info import DctProductTelemetryBundleLicenseInfo
from delphix.api.gateway.model.dct_product_telemetry_bundle_object_counts import DCTProductTelemetryBundleObjectCounts
from delphix.api.gateway.model.dct_product_telemetry_bundle_product_info import DctProductTelemetryBundleProductInfo
from delphix.api.gateway.model.dct_product_telemetry_bundle_registered_engine import DctProductTelemetryBundleRegisteredEngine
from delphix.api.gateway.model.dct_product_telemetry_bundle_rule_set import DctProductTelemetryBundleRuleSet
from delphix.api.gateway.model.dct_product_telemetry_bundle_vdb_info import DCTProductTelemetryBundleVDBInfo
from delphix.api.gateway.model.dct_product_telemetry_data_connection import DctProductTelemetryDataConnection
globals()['DCTProductTelemetryBundleAdministrationInfo'] = DCTProductTelemetryBundleAdministrationInfo
globals()['DCTProductTelemetryBundleDSourceInfo'] = DCTProductTelemetryBundleDSourceInfo
globals()['DCTProductTelemetryBundleEnvironmentInfo'] = DCTProductTelemetryBundleEnvironmentInfo
globals()['DCTProductTelemetryBundleObjectCounts'] = DCTProductTelemetryBundleObjectCounts
globals()['DCTProductTelemetryBundleVDBInfo'] = DCTProductTelemetryBundleVDBInfo
globals()['DctProductTelemetryBundleApiTelemetry'] = DctProductTelemetryBundleApiTelemetry
globals()['DctProductTelemetryBundleComplianceJob'] = DctProductTelemetryBundleComplianceJob
globals()['DctProductTelemetryBundleComplianceNode'] = DctProductTelemetryBundleComplianceNode
globals()['DctProductTelemetryBundleComplianceObjectCounts'] = DctProductTelemetryBundleComplianceObjectCounts
globals()['DctProductTelemetryBundleConnector'] = DctProductTelemetryBundleConnector
globals()['DctProductTelemetryBundleContinuousDataEngineStorage'] = DctProductTelemetryBundleContinuousDataEngineStorage
globals()['DctProductTelemetryBundleDataConnectionStorage'] = DctProductTelemetryBundleDataConnectionStorage
globals()['DctProductTelemetryBundleExecution'] = DctProductTelemetryBundleExecution
globals()['DctProductTelemetryBundleHyperscaleOrchestrator'] = DctProductTelemetryBundleHyperscaleOrchestrator
globals()['DctProductTelemetryBundleJobOrchestrator'] = DctProductTelemetryBundleJobOrchestrator
globals()['DctProductTelemetryBundleLicenseInfo'] = DctProductTelemetryBundleLicenseInfo
globals()['DctProductTelemetryBundleProductInfo'] = DctProductTelemetryBundleProductInfo
globals()['DctProductTelemetryBundleRegisteredEngine'] = DctProductTelemetryBundleRegisteredEngine
globals()['DctProductTelemetryBundleRuleSet'] = DctProductTelemetryBundleRuleSet
globals()['DctProductTelemetryDataConnection'] = DctProductTelemetryDataConnection
from delphix.api.gateway.model.dct_product_telemetry_bundle import DctProductTelemetryBundle


class TestDctProductTelemetryBundle(unittest.TestCase):
    """DctProductTelemetryBundle unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDctProductTelemetryBundle(self):
        """Test DctProductTelemetryBundle"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DctProductTelemetryBundle()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
