"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.paa_s_plugins_api import PaaSPluginsApi  # noqa: E501


class TestPaaSPluginsApi(unittest.TestCase):
    """PaaSPluginsApi unit test stubs"""

    def setUp(self):
        self.api = PaaSPluginsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_paas_plugin_tags(self):
        """Test case for create_paas_plugin_tags

        Create tags for a PaaS plugin.  # noqa: E501
        """
        pass

    def test_delete_paas_plugin_tags(self):
        """Test case for delete_paas_plugin_tags

        Delete tags for a PaaS Plugin.  # noqa: E501
        """
        pass

    def test_get_paas_plugin_tags(self):
        """Test case for get_paas_plugin_tags

        Get tags for a PaaS Plugin.  # noqa: E501
        """
        pass

    def test_get_paas_plugins(self):
        """Test case for get_paas_plugins

        List all registered PaaS plugins.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
