"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.jobs_api import JobsApi  # noqa: E501


class TestJobsApi(unittest.TestCase):
    """JobsApi unit test stubs"""

    def setUp(self):
        self.api = JobsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_abandon_job(self):
        """Test case for abandon_job

        Abandons a job.  # noqa: E501
        """
        pass

    def test_create_job_tags(self):
        """Test case for create_job_tags

        Create tags for a Job.  # noqa: E501
        """
        pass

    def test_delete_job_tag(self):
        """Test case for delete_job_tag

        Delete tags for a Job.  # noqa: E501
        """
        pass

    def test_get_job_by_id(self):
        """Test case for get_job_by_id

        Returns a job by ID.  # noqa: E501
        """
        pass

    def test_get_job_result(self):
        """Test case for get_job_result

        Get job result.  # noqa: E501
        """
        pass

    def test_get_job_tags(self):
        """Test case for get_job_tags

        Get tags for a Job.  # noqa: E501
        """
        pass

    def test_get_jobs(self):
        """Test case for get_jobs

        List all jobs.  # noqa: E501
        """
        pass

    def test_search_jobs(self):
        """Test case for search_jobs

        Search for jobs.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
