"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.policy_target_object import PolicyTargetObject
from delphix.api.gateway.model.policy_type import PolicyType
from delphix.api.gateway.model.provision_source import ProvisionSource
from delphix.api.gateway.model.tag import Tag
from delphix.api.gateway.model.virtualization_schedule import VirtualizationSchedule
globals()['PolicyTargetObject'] = PolicyTargetObject
globals()['PolicyType'] = PolicyType
globals()['ProvisionSource'] = ProvisionSource
globals()['Tag'] = Tag
globals()['VirtualizationSchedule'] = VirtualizationSchedule
from delphix.api.gateway.model.create_virtualization_policy_parameters import CreateVirtualizationPolicyParameters


class TestCreateVirtualizationPolicyParameters(unittest.TestCase):
    """CreateVirtualizationPolicyParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateVirtualizationPolicyParameters(self):
        """Test CreateVirtualizationPolicyParameters"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateVirtualizationPolicyParameters()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
