"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.ai_generate_api import AiGenerateApi  # noqa: E501


class TestAiGenerateApi(unittest.TestCase):
    """AiGenerateApi unit test stubs"""

    def setUp(self):
        self.api = AiGenerateApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_download_generate_values(self):
        """Test case for download_generate_values

        Download all values generated by the operation in the specified format  # noqa: E501
        """
        pass

    def test_generate_data(self):
        """Test case for generate_data

        Initiate an operation that creates a list of data values using generative AI  # noqa: E501
        """
        pass

    def test_get_all_generate_operations(self):
        """Test case for get_all_generate_operations

        Get the details of all data generate operations  # noqa: E501
        """
        pass

    def test_get_generate_operation(self):
        """Test case for get_generate_operation

        Get the details of a data generate operation  # noqa: E501
        """
        pass

    def test_get_generate_values(self):
        """Test case for get_generate_values

        Get all values generated by a data generate operation  # noqa: E501
        """
        pass

    def test_search_all_generate_operations(self):
        """Test case for search_all_generate_operations

        Search for the details of data generate operations  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
