"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.network_performance_tool_api import NetworkPerformanceToolApi  # noqa: E501


class TestNetworkPerformanceToolApi(unittest.TestCase):
    """NetworkPerformanceToolApi unit test stubs"""

    def setUp(self):
        self.api = NetworkPerformanceToolApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_dsp_test(self):
        """Test case for create_dsp_test

        Create DSP Network Performance Test  # noqa: E501
        """
        pass

    def test_create_latency_test(self):
        """Test case for create_latency_test

        Create Latency Network Performance Test  # noqa: E501
        """
        pass

    def test_create_throughput_test(self):
        """Test case for create_throughput_test

        Create Throughput Network Performance Test  # noqa: E501
        """
        pass

    def test_get_dsp_test_result(self):
        """Test case for get_dsp_test_result

        Retrieve Network DSP Test Result  # noqa: E501
        """
        pass

    def test_get_latency_test_result(self):
        """Test case for get_latency_test_result

        Retrieve Network Latency Test Result  # noqa: E501
        """
        pass

    def test_get_throughput_test_result(self):
        """Test case for get_throughput_test_result

        Retrieve Network Throughput Test Result  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
