"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.staging_sources_api import StagingSourcesApi  # noqa: E501


class TestStagingSourcesApi(unittest.TestCase):
    """StagingSourcesApi unit test stubs"""

    def setUp(self):
        self.api = StagingSourcesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_staging_source_tags(self):
        """Test case for create_staging_source_tags

        Create tags for a Staging Source.  # noqa: E501
        """
        pass

    def test_delete_staging_source_tags(self):
        """Test case for delete_staging_source_tags

        Delete tags for a Staging Source.  # noqa: E501
        """
        pass

    def test_get_staging_source_by_id(self):
        """Test case for get_staging_source_by_id

        Get a staging source by ID.  # noqa: E501
        """
        pass

    def test_get_staging_source_tags(self):
        """Test case for get_staging_source_tags

        Get tags for a Staging Source.  # noqa: E501
        """
        pass

    def test_get_staging_sources(self):
        """Test case for get_staging_sources

        List all staging sources.  # noqa: E501
        """
        pass

    def test_search_staging_sources(self):
        """Test case for search_staging_sources

        Search for Staging Sources.  # noqa: E501
        """
        pass

    def test_update_staging_source_by_id(self):
        """Test case for update_staging_source_by_id

        Update a Staging Source.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
