"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.compliance_jobs_api import ComplianceJobsApi  # noqa: E501


class TestComplianceJobsApi(unittest.TestCase):
    """ComplianceJobsApi unit test stubs"""

    def setUp(self):
        self.api = ComplianceJobsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_compliance_job(self):
        """Test case for create_compliance_job

        Create a Compliance Job.  # noqa: E501
        """
        pass

    def test_create_compliance_job_tag(self):
        """Test case for create_compliance_job_tag

        Create tags for a compliance job.  # noqa: E501
        """
        pass

    def test_delete_compliance_job(self):
        """Test case for delete_compliance_job

        Delete a compliance job.  # noqa: E501
        """
        pass

    def test_delete_compliance_job_tag(self):
        """Test case for delete_compliance_job_tag

        Delete tags for a compliance job.  # noqa: E501
        """
        pass

    def test_execute_compliance_job(self):
        """Test case for execute_compliance_job

        Execute a compliance job.  # noqa: E501
        """
        pass

    def test_get_compliance_job_by_id(self):
        """Test case for get_compliance_job_by_id

        Retrieve a compliance job by ID.  # noqa: E501
        """
        pass

    def test_get_compliance_job_connectors(self):
        """Test case for get_compliance_job_connectors

        Get connectors for a Masking Job by ID.  # noqa: E501
        """
        pass

    def test_get_compliance_job_tag(self):
        """Test case for get_compliance_job_tag

        Get tags for a compliance job.  # noqa: E501
        """
        pass

    def test_get_compliance_jobs(self):
        """Test case for get_compliance_jobs

        Retrieve the list of compliance jobs.  # noqa: E501
        """
        pass

    def test_search_compliance_jobs(self):
        """Test case for search_compliance_jobs

        Search compliance jobs.  # noqa: E501
        """
        pass

    def test_update_compliance_job(self):
        """Test case for update_compliance_job

        Update values of a compliance job.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
