"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.paginated_response_metadata import PaginatedResponseMetadata
from delphix.api.gateway.model.queued_operation import QueuedOperation
globals()['PaginatedResponseMetadata'] = PaginatedResponseMetadata
globals()['QueuedOperation'] = QueuedOperation
from delphix.api.gateway.model.list_job_orchestrator_queued_operations_response import ListJobOrchestratorQueuedOperationsResponse


class TestListJobOrchestratorQueuedOperationsResponse(unittest.TestCase):
    """ListJobOrchestratorQueuedOperationsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListJobOrchestratorQueuedOperationsResponse(self):
        """Test ListJobOrchestratorQueuedOperationsResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListJobOrchestratorQueuedOperationsResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
