"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.staging_cdbs_api import StagingCdbsApi  # noqa: E501


class TestStagingCdbsApi(unittest.TestCase):
    """StagingCdbsApi unit test stubs"""

    def setUp(self):
        self.api = StagingCdbsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_staging_cdb_tags(self):
        """Test case for create_staging_cdb_tags

        Create tags for a staging CDB.  # noqa: E501
        """
        pass

    def test_delete_staging_cdb(self):
        """Test case for delete_staging_cdb

        Delete a staging CDB.  # noqa: E501
        """
        pass

    def test_delete_staging_cdb_tags(self):
        """Test case for delete_staging_cdb_tags

        Delete tags for a staging CDB.  # noqa: E501
        """
        pass

    def test_disable_staging_cdb(self):
        """Test case for disable_staging_cdb

        Disable a staging CDB.  # noqa: E501
        """
        pass

    def test_enable_staging_cdb(self):
        """Test case for enable_staging_cdb

        Enable a staging CDB.  # noqa: E501
        """
        pass

    def test_get_staging_cdb_by_id(self):
        """Test case for get_staging_cdb_by_id

        Get a Staging CDB by ID.  # noqa: E501
        """
        pass

    def test_get_staging_cdb_tags(self):
        """Test case for get_staging_cdb_tags

        Get tags for a staging CDB.  # noqa: E501
        """
        pass

    def test_get_staging_cdbs(self):
        """Test case for get_staging_cdbs

        List all Staging CDBs.  # noqa: E501
        """
        pass

    def test_search_staging_cdbs(self):
        """Test case for search_staging_cdbs

        Search for Staging CDBs.  # noqa: E501
        """
        pass

    def test_update_staging_cdb(self):
        """Test case for update_staging_cdb

        Update a Staging CDB.  # noqa: E501
        """
        pass

    def test_upgrade_staging_cdb(self):
        """Test case for upgrade_staging_cdb

        Upgrade Oracle staging CDB.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
