"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.paa_s_databases_api import PaaSDatabasesApi  # noqa: E501


class TestPaaSDatabasesApi(unittest.TestCase):
    """PaaSDatabasesApi unit test stubs"""

    def setUp(self):
        self.api = PaaSDatabasesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_paas_database_compliance_connector(self):
        """Test case for create_paas_database_compliance_connector

        Create a new compliance connector for the PaaS Database.  # noqa: E501
        """
        pass

    def test_create_paas_database_tags(self):
        """Test case for create_paas_database_tags

        Create tags for a PaaS Database.  # noqa: E501
        """
        pass

    def test_delete_paas_database(self):
        """Test case for delete_paas_database

        Delete a PaaS Database  # noqa: E501
        """
        pass

    def test_delete_paas_database_tags(self):
        """Test case for delete_paas_database_tags

        Delete tags for a PaaS Database.  # noqa: E501
        """
        pass

    def test_deprovision_paas_database(self):
        """Test case for deprovision_paas_database

        De-provision a PaaS Database, meaning that the database object will remain in DCT, along with its permissions, tags, snapshots, ... but the database will no longer be running. If the current database data must be preserved, take a snapshot before de-provisioning.  # noqa: E501
        """
        pass

    def test_execute_paas_database_compliance_job(self):
        """Test case for execute_paas_database_compliance_job

        Execute the compliance job for a PaaS Database  # noqa: E501
        """
        pass

    def test_get_paas_database_by_id(self):
        """Test case for get_paas_database_by_id

        Get a PaaS Database by ID.  # noqa: E501
        """
        pass

    def test_get_paas_database_tags(self):
        """Test case for get_paas_database_tags

        Get tags for a PaaS Database.  # noqa: E501
        """
        pass

    def test_get_paas_databases(self):
        """Test case for get_paas_databases

        List all PaaS Databases.  # noqa: E501
        """
        pass

    def test_provision_paas_database(self):
        """Test case for provision_paas_database

        Provision a new PaaS Database  # noqa: E501
        """
        pass

    def test_provision_paas_database_from_bookmark(self):
        """Test case for provision_paas_database_from_bookmark

        Provision a new PaaS Database from a bookmark  # noqa: E501
        """
        pass

    def test_refresh_paas_database(self):
        """Test case for refresh_paas_database

        Refresh a PaaS Database  # noqa: E501
        """
        pass

    def test_refresh_paas_database_from_bookmark(self):
        """Test case for refresh_paas_database_from_bookmark

        Refresh a PaaS Database from bookmark  # noqa: E501
        """
        pass

    def test_reprovision_paas_database(self):
        """Test case for reprovision_paas_database

        Re-provision a PaaS Database which has previously been de-provisioned. The provision parameters specified at provisioning time will be respected, with the exception of the timestamp or snapshot id to re-provision from.  # noqa: E501
        """
        pass

    def test_search_paas_databases(self):
        """Test case for search_paas_databases

        Search for PaaS Databases.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
