"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.paa_s_instances_api import PaaSInstancesApi  # noqa: E501


class TestPaaSInstancesApi(unittest.TestCase):
    """PaaSInstancesApi unit test stubs"""

    def setUp(self):
        self.api = PaaSInstancesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_paas_instance_tags(self):
        """Test case for create_paas_instance_tags

        Create tags for a PaaS Instance.  # noqa: E501
        """
        pass

    def test_delete_paas_instance(self):
        """Test case for delete_paas_instance

        Delete a PaaS Instance  # noqa: E501
        """
        pass

    def test_delete_paas_instance_tags(self):
        """Test case for delete_paas_instance_tags

        Delete tags for a PaaS Instance.  # noqa: E501
        """
        pass

    def test_deprovision_paas_instance(self):
        """Test case for deprovision_paas_instance

        De-provision a PaaS Instance, meaning that the instance object will remain in DCT, along with its permissions, tags, snapshots, ... but the instance will no longer be running. If the current instance data must be preserved, take a snapshot before de-provisioning.  # noqa: E501
        """
        pass

    def test_get_paas_instance_by_id(self):
        """Test case for get_paas_instance_by_id

        Get a PaaS Instance by ID.  # noqa: E501
        """
        pass

    def test_get_paas_instance_tags(self):
        """Test case for get_paas_instance_tags

        Get tags for a PaaS Instance.  # noqa: E501
        """
        pass

    def test_get_paas_instances(self):
        """Test case for get_paas_instances

        List all PaaS Instances.  # noqa: E501
        """
        pass

    def test_provision_paas_instance(self):
        """Test case for provision_paas_instance

        Provision a new PaaS Instance  # noqa: E501
        """
        pass

    def test_provision_paas_instance_from_bookmark(self):
        """Test case for provision_paas_instance_from_bookmark

        Provision a new PaaS Instance from a bookmark  # noqa: E501
        """
        pass

    def test_refresh_paas_instance(self):
        """Test case for refresh_paas_instance

        Refresh a PaaS Instance  # noqa: E501
        """
        pass

    def test_refresh_paas_instance_from_bookmark(self):
        """Test case for refresh_paas_instance_from_bookmark

        Refresh a PaaS Instance from a bookmark  # noqa: E501
        """
        pass

    def test_reprovision_paas_instance(self):
        """Test case for reprovision_paas_instance

        Re-provision a PaaS Instance which has previously been de-provisioned. The provision parameters specified at provisioning time will be respected, with the exception of the timestamp or snapshot id to re-provision from.  # noqa: E501
        """
        pass

    def test_search_paas_instances(self):
        """Test case for search_paas_instances

        Search for PaaS Instances.  # noqa: E501
        """
        pass

    def test_start_paas_instance(self):
        """Test case for start_paas_instance

        Start a PaaS Instance  # noqa: E501
        """
        pass

    def test_stop_paas_instance(self):
        """Test case for stop_paas_instance

        Stop a PaaS Instance  # noqa: E501
        """
        pass

    def test_update_paas_instance(self):
        """Test case for update_paas_instance

        Update a PaaS Instance.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
