"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.compliance_nodes_api import ComplianceNodesApi  # noqa: E501


class TestComplianceNodesApi(unittest.TestCase):
    """ComplianceNodesApi unit test stubs"""

    def setUp(self):
        self.api = ComplianceNodesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_compliance_node(self):
        """Test case for delete_compliance_node

        Delete a compliance node.  # noqa: E501
        """
        pass

    def test_get_compliance_node_by_id(self):
        """Test case for get_compliance_node_by_id

        Retrieve a compliance node by ID.  # noqa: E501
        """
        pass

    def test_get_compliance_nodes(self):
        """Test case for get_compliance_nodes

        """
        pass

    def test_get_log_content(self):
        """Test case for get_log_content

        Get log content for a compliance node.  # noqa: E501
        """
        pass

    def test_get_log_file_details(self):
        """Test case for get_log_file_details

        Get log file details for a compliance node.  # noqa: E501
        """
        pass

    def test_refresh_logs(self):
        """Test case for refresh_logs

        Refresh the logs for a compliance node.  # noqa: E501
        """
        pass

    def test_register_compliance_node(self):
        """Test case for register_compliance_node

        Register a compliance node  # noqa: E501
        """
        pass

    def test_search_compliance_nodes(self):
        """Test case for search_compliance_nodes

        Search for compliance nodes  # noqa: E501
        """
        pass

    def test_update_compliance_node(self):
        """Test case for update_compliance_node

        Update a compliance node.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
