"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.hyperscale_dataset import HyperscaleDataset
from delphix.api.gateway.model.paginated_response_metadata import PaginatedResponseMetadata
globals()['HyperscaleDataset'] = HyperscaleDataset
globals()['PaginatedResponseMetadata'] = PaginatedResponseMetadata
from delphix.api.gateway.model.search_hyperscale_datasets_response import SearchHyperscaleDatasetsResponse


class TestSearchHyperscaleDatasetsResponse(unittest.TestCase):
    """SearchHyperscaleDatasetsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSearchHyperscaleDatasetsResponse(self):
        """Test SearchHyperscaleDatasetsResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SearchHyperscaleDatasetsResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
