"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.accounts_api import AccountsApi  # noqa: E501


class TestAccountsApi(unittest.TestCase):
    """AccountsApi unit test stubs"""

    def setUp(self):
        self.api = AccountsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_key_delete(self):
        """Test case for api_key_delete

        Delete an API Key for an account  # noqa: E501
        """
        pass

    def test_api_key_regenerate(self):
        """Test case for api_key_regenerate

        Regenerate api key for the self.  # noqa: E501
        """
        pass

    def test_api_key_reset(self):
        """Test case for api_key_reset

        Reset account API key.  # noqa: E501
        """
        pass

    def test_change_account_password(self):
        """Test case for change_account_password

        Change Account Password.   # noqa: E501
        """
        pass

    def test_create_account(self):
        """Test case for create_account

        Create a new Account   # noqa: E501
        """
        pass

    def test_create_account_tags(self):
        """Test case for create_account_tags

        Create tags for an Account.  # noqa: E501
        """
        pass

    def test_delete_account(self):
        """Test case for delete_account

        Delete an Account  # noqa: E501
        """
        pass

    def test_delete_account_tags(self):
        """Test case for delete_account_tags

        Delete tags for an Account.  # noqa: E501
        """
        pass

    def test_disable(self):
        """Test case for disable

        Disable an Account.  # noqa: E501
        """
        pass

    def test_enable_account(self):
        """Test case for enable_account

        Enable an Account.  # noqa: E501
        """
        pass

    def test_get_account(self):
        """Test case for get_account

        Get an Account by id  # noqa: E501
        """
        pass

    def test_get_account_tags(self):
        """Test case for get_account_tags

        Get tags for an Account.  # noqa: E501
        """
        pass

    def test_get_account_ui_profiles(self):
        """Test case for get_account_ui_profiles

        Returns the list of effective UI profiles for an account. This can only be called for one's own account.  # noqa: E501
        """
        pass

    def test_get_accounts(self):
        """Test case for get_accounts

        Returns a list of Accounts  # noqa: E501
        """
        pass

    def test_get_password_policies(self):
        """Test case for get_password_policies

        Returns the password policies  # noqa: E501
        """
        pass

    def test_reset_account_password(self):
        """Test case for reset_account_password

        Reset Account Password.   # noqa: E501
        """
        pass

    def test_search_accounts(self):
        """Test case for search_accounts

        Search for Accounts.  # noqa: E501
        """
        pass

    def test_update_account(self):
        """Test case for update_account

        Update an Account   # noqa: E501
        """
        pass

    def test_update_password_policies(self):
        """Test case for update_password_policies

        Update password policies.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
