"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.paa_s_snapshots_api import PaaSSnapshotsApi  # noqa: E501


class TestPaaSSnapshotsApi(unittest.TestCase):
    """PaaSSnapshotsApi unit test stubs"""

    def setUp(self):
        self.api = PaaSSnapshotsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_paas_snapshot_tags(self):
        """Test case for create_paas_snapshot_tags

        Create tags for a PaaS Snapshot.  # noqa: E501
        """
        pass

    def test_delete_paas_snapshot_tags(self):
        """Test case for delete_paas_snapshot_tags

        Delete tags for a PaaS Snapshot.  # noqa: E501
        """
        pass

    def test_get_all_paas_snapshots(self):
        """Test case for get_all_paas_snapshots

        Get all PaaS Snapshots  # noqa: E501
        """
        pass

    def test_get_paas_snapshot_by_id(self):
        """Test case for get_paas_snapshot_by_id

        Get PaaS Snapshot by ID  # noqa: E501
        """
        pass

    def test_get_paas_snapshot_tags(self):
        """Test case for get_paas_snapshot_tags

        Get tags for a PaaS Snapshot.  # noqa: E501
        """
        pass

    def test_search_paas_snapshots(self):
        """Test case for search_paas_snapshots

        Search PaaS Snapshots  # noqa: E501
        """
        pass

    def test_share_paas_snapshot(self):
        """Test case for share_paas_snapshot

        share PaaS Snapshots and make it public  # noqa: E501
        """
        pass

    def test_unshare_paas_snapshot(self):
        """Test case for unshare_paas_snapshot

        un-share PaaS Snapshots and make it public  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
