"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.data_library_api import DataLibraryApi  # noqa: E501


class TestDataLibraryApi(unittest.TestCase):
    """DataLibraryApi unit test stubs"""

    def setUp(self):
        self.api = DataLibraryApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_data_library(self):
        """Test case for get_data_library

        Get data library objects.  # noqa: E501
        """
        pass

    def test_search_data_library(self):
        """Test case for search_data_library

        Search data library objects.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
