"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.login_api import LoginApi  # noqa: E501


class TestLoginApi(unittest.TestCase):
    """LoginApi unit test stubs"""

    def setUp(self):
        self.api = LoginApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_account_login(self):
        """Test case for account_login

        Login to Account with Username and Password   # noqa: E501
        """
        pass

    def test_account_logout(self):
        """Test case for account_logout

        Invalidates username/password and SSO login session.  # noqa: E501
        """
        pass

    def test_token_info(self):
        """Test case for token_info

        Get Token Information   # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
