"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.base_export_transfer_strategy_parameters import BaseExportTransferStrategyParameters
from delphix.api.gateway.model.export_by_timestamp_parameters_all_of import ExportByTimestampParametersAllOf
from delphix.api.gateway.model.export_db_timeflow_point_parameters import ExportDBTimeflowPointParameters
from delphix.api.gateway.model.oracle_asm_layout_parameters import OracleAsmLayoutParameters
from delphix.api.gateway.model.oracle_rac_database_instance import OracleRACDatabaseInstance
from delphix.api.gateway.model.oracle_tde_keystore_config_type_enum import OracleTdeKeystoreConfigTypeEnum
globals()['BaseExportTransferStrategyParameters'] = BaseExportTransferStrategyParameters
globals()['ExportByTimestampParametersAllOf'] = ExportByTimestampParametersAllOf
globals()['ExportDBTimeflowPointParameters'] = ExportDBTimeflowPointParameters
globals()['OracleAsmLayoutParameters'] = OracleAsmLayoutParameters
globals()['OracleRACDatabaseInstance'] = OracleRACDatabaseInstance
globals()['OracleTdeKeystoreConfigTypeEnum'] = OracleTdeKeystoreConfigTypeEnum
from delphix.api.gateway.model.oracle_asm_export_by_timestamp_parameters import OracleAsmExportByTimestampParameters


class TestOracleAsmExportByTimestampParameters(unittest.TestCase):
    """OracleAsmExportByTimestampParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOracleAsmExportByTimestampParameters(self):
        """Test OracleAsmExportByTimestampParameters"""
        # FIXME: construct object with mandatory attributes with example values
        # model = OracleAsmExportByTimestampParameters()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
