"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.connectors_api import ConnectorsApi  # noqa: E501


class TestConnectorsApi(unittest.TestCase):
    """ConnectorsApi unit test stubs"""

    def setUp(self):
        self.api = ConnectorsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_connector(self):
        """Test case for create_connector

        Create a Connector.  # noqa: E501
        """
        pass

    def test_create_connector_tags(self):
        """Test case for create_connector_tags

        Create tags for a Connector.  # noqa: E501
        """
        pass

    def test_delete_connector(self):
        """Test case for delete_connector

        Delete a DCT managed masking connector.  # noqa: E501
        """
        pass

    def test_delete_connector_tag(self):
        """Test case for delete_connector_tag

        Delete tags for a Connector.  # noqa: E501
        """
        pass

    def test_fetch_table_names(self):
        """Test case for fetch_table_names

        Return the name of all tables accessible by the database user.  # noqa: E501
        """
        pass

    def test_get_connection_properties(self):
        """Test case for get_connection_properties

        Retrieve the combined properties from jdbc-driver and the properties-file of the connector.  # noqa: E501
        """
        pass

    def test_get_connector_by_id(self):
        """Test case for get_connector_by_id

        Retrieve a masking Connector by ID.  # noqa: E501
        """
        pass

    def test_get_connector_driver_support_tasks(self):
        """Test case for get_connector_driver_support_tasks

        Retrieve driver support tasks for a connector.  # noqa: E501
        """
        pass

    def test_get_connector_tags(self):
        """Test case for get_connector_tags

        Get tags for a Connector.  # noqa: E501
        """
        pass

    def test_get_connectors(self):
        """Test case for get_connectors

        Retrieve the list of masking connectors.  # noqa: E501
        """
        pass

    def test_search_connector_jobs(self):
        """Test case for search_connector_jobs

        Search jobs that use this connector  # noqa: E501
        """
        pass

    def test_search_connectors(self):
        """Test case for search_connectors

        Search for masking Connectors.  # noqa: E501
        """
        pass

    def test_test_connector(self):
        """Test case for test_connector

        Checks connectivity of the connector  # noqa: E501
        """
        pass

    def test_test_unsaved_connector(self):
        """Test case for test_unsaved_connector

        Checks connectivity of an unsaved remote data source.  # noqa: E501
        """
        pass

    def test_update_connector_by_id(self):
        """Test case for update_connector_by_id

        Update a masking Connector by ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
