"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.network_dsp_test_request import NetworkDSPTestRequest
from delphix.api.gateway.model.network_dsp_test_result_all_of import NetworkDSPTestResultAllOf
from delphix.api.gateway.model.network_test_base_result import NetworkTestBaseResult
globals()['NetworkDSPTestRequest'] = NetworkDSPTestRequest
globals()['NetworkDSPTestResultAllOf'] = NetworkDSPTestResultAllOf
globals()['NetworkTestBaseResult'] = NetworkTestBaseResult
from delphix.api.gateway.model.network_dsp_test_result import NetworkDSPTestResult


class TestNetworkDSPTestResult(unittest.TestCase):
    """NetworkDSPTestResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkDSPTestResult(self):
        """Test NetworkDSPTestResult"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkDSPTestResult()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
