"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.license_api import LicenseApi  # noqa: E501


class TestLicenseApi(unittest.TestCase):
    """LicenseApi unit test stubs"""

    def setUp(self):
        self.api = LicenseApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_change_license(self):
        """Test case for change_license

        Change the current DCT license.  # noqa: E501
        """
        pass

    def test_get_license(self):
        """Test case for get_license

        Returns the DCT license information.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
