"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.ai_management_api import AiManagementApi  # noqa: E501


class TestAiManagementApi(unittest.TestCase):
    """AiManagementApi unit test stubs"""

    def setUp(self):
        self.api = AiManagementApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_all_llm_gateways(self):
        """Test case for get_all_llm_gateways

        Get the details of all available gateways  # noqa: E501
        """
        pass

    def test_get_all_llm_models(self):
        """Test case for get_all_llm_models

        Get the details of all available Llm models  # noqa: E501
        """
        pass

    def test_get_llm_model(self):
        """Test case for get_llm_model

        Get the details of an LLM model  # noqa: E501
        """
        pass

    def test_upload_model(self):
        """Test case for upload_model

        Upload the model file and register it with Ollama service  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
