"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.virtualization_policies_api import VirtualizationPoliciesApi  # noqa: E501


class TestVirtualizationPoliciesApi(unittest.TestCase):
    """VirtualizationPoliciesApi unit test stubs"""

    def setUp(self):
        self.api = VirtualizationPoliciesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_apply_virtualization_policy_by_id_or_name(self):
        """Test case for apply_virtualization_policy_by_id_or_name

        Apply a virtualization policy to the given list of objects.  # noqa: E501
        """
        pass

    def test_convert_virtualization_policy(self):
        """Test case for convert_virtualization_policy

        Convert a virtualization policy to a DCT-managed policy.  # noqa: E501
        """
        pass

    def test_create_virtualization_policy(self):
        """Test case for create_virtualization_policy

        Create a VirtualizationPolicy.  # noqa: E501
        """
        pass

    def test_create_virtualization_policy_tags(self):
        """Test case for create_virtualization_policy_tags

        Create tags for a VirtualizationPolicy.  # noqa: E501
        """
        pass

    def test_delete_virtualization_policy(self):
        """Test case for delete_virtualization_policy

        Delete a VirtualizationPolicy.  # noqa: E501
        """
        pass

    def test_delete_virtualization_policy_tags(self):
        """Test case for delete_virtualization_policy_tags

        Delete tags for a VirtualizationPolicy.  # noqa: E501
        """
        pass

    def test_get_virtualization_policy_by_id(self):
        """Test case for get_virtualization_policy_by_id

        Fetch a virtualization policy by Id.  # noqa: E501
        """
        pass

    def test_get_virtualization_policy_tags(self):
        """Test case for get_virtualization_policy_tags

        Get tags for a VirtualizationPolicy.  # noqa: E501
        """
        pass

    def test_list_virtualization_policies(self):
        """Test case for list_virtualization_policies

        Fetch a list of all virtualization policies  # noqa: E501
        """
        pass

    def test_search_virtualization_policies(self):
        """Test case for search_virtualization_policies

        Search Virtualization Policies.  # noqa: E501
        """
        pass

    def test_search_virtualization_policy_targets(self):
        """Test case for search_virtualization_policy_targets

        Search Virtualization Policy Target Objects.  # noqa: E501
        """
        pass

    def test_unapply_virtualization_policy_by_id_or_name(self):
        """Test case for unapply_virtualization_policy_by_id_or_name

        Unapply a virtualization policy to the given list of objects.  # noqa: E501
        """
        pass

    def test_update_virtualization_policy(self):
        """Test case for update_virtualization_policy

        Update a VirtualizationPolicy.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
