"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.license_usage_response_current_sources_size import LicenseUsageResponseCurrentSourcesSize
from delphix.api.gateway.model.license_usage_response_other_entitlements import LicenseUsageResponseOtherEntitlements
from delphix.api.gateway.model.license_usage_response_source_type_count import LicenseUsageResponseSourceTypeCount
globals()['LicenseUsageResponseCurrentSourcesSize'] = LicenseUsageResponseCurrentSourcesSize
globals()['LicenseUsageResponseOtherEntitlements'] = LicenseUsageResponseOtherEntitlements
globals()['LicenseUsageResponseSourceTypeCount'] = LicenseUsageResponseSourceTypeCount
from delphix.api.gateway.model.license_usage_response import LicenseUsageResponse


class TestLicenseUsageResponse(unittest.TestCase):
    """LicenseUsageResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testLicenseUsageResponse(self):
        """Test LicenseUsageResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = LicenseUsageResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
