"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.rule_sets_api import RuleSetsApi  # noqa: E501


class TestRuleSetsApi(unittest.TestCase):
    """RuleSetsApi unit test stubs"""

    def setUp(self):
        self.api = RuleSetsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_bulk_table_delta_update_rule_set(self):
        """Test case for bulk_table_delta_update_rule_set

        Update the set of tables and their attributes associated with a database rule set in bulk in a delta fashion.  # noqa: E501
        """
        pass

    def test_create_rule_set(self):
        """Test case for create_rule_set

        Create a Rule Set.  # noqa: E501
        """
        pass

    def test_create_rule_set_tags(self):
        """Test case for create_rule_set_tags

        Create tags for a Rule Set.  # noqa: E501
        """
        pass

    def test_delete_rule_set(self):
        """Test case for delete_rule_set

        Delete a Rule Set.  # noqa: E501
        """
        pass

    def test_delete_rule_set_tags(self):
        """Test case for delete_rule_set_tags

        Delete tags for a Rule Set.  # noqa: E501
        """
        pass

    def test_get_database_column_metadata(self):
        """Test case for get_database_column_metadata

        Retrieve column metadata.  # noqa: E501
        """
        pass

    def test_get_database_column_metadata_by_id(self):
        """Test case for get_database_column_metadata_by_id

        Retrieve a database column metadata by ID.  # noqa: E501
        """
        pass

    def test_get_database_table_metadata(self):
        """Test case for get_database_table_metadata

        Retrieve table metadata.  # noqa: E501
        """
        pass

    def test_get_database_table_metadata_by_id(self):
        """Test case for get_database_table_metadata_by_id

        Retrieve a database table metadata by ID.  # noqa: E501
        """
        pass

    def test_get_rule_set_by_id(self):
        """Test case for get_rule_set_by_id

        Get a Rule Set by ID.  # noqa: E501
        """
        pass

    def test_get_rule_set_tags(self):
        """Test case for get_rule_set_tags

        Get tags for a Rule Set.  # noqa: E501
        """
        pass

    def test_get_rule_sets(self):
        """Test case for get_rule_sets

        Retrieve the list of Rule Sets.  # noqa: E501
        """
        pass

    def test_refresh_rule_set(self):
        """Test case for refresh_rule_set

        Refresh a Rule Set.  # noqa: E501
        """
        pass

    def test_search_database_column_metadata(self):
        """Test case for search_database_column_metadata

        Search column metadata.  # noqa: E501
        """
        pass

    def test_search_database_table_metadata(self):
        """Test case for search_database_table_metadata

        Search table metadata.  # noqa: E501
        """
        pass

    def test_search_rule_sets(self):
        """Test case for search_rule_sets

        Search for Rule Sets.  # noqa: E501
        """
        pass

    def test_update_database_column_metadata(self):
        """Test case for update_database_column_metadata

        Update a database column metadata  # noqa: E501
        """
        pass

    def test_update_rule_set(self):
        """Test case for update_rule_set

        Update a Rule Set.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
