"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.reporting_api import ReportingApi  # noqa: E501


class TestReportingApi(unittest.TestCase):
    """ReportingApi unit test stubs"""

    def setUp(self):
        self.api = ReportingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_reporting_schedule(self):
        """Test case for create_reporting_schedule

        Create a new report schedule.  # noqa: E501
        """
        pass

    def test_create_reporting_schedule_tags(self):
        """Test case for create_reporting_schedule_tags

        Create tags for a report schedule.  # noqa: E501
        """
        pass

    def test_delete_reporting_schedule(self):
        """Test case for delete_reporting_schedule

        Delete report schedule by ID.  # noqa: E501
        """
        pass

    def test_delete_reporting_schedule_tag(self):
        """Test case for delete_reporting_schedule_tag

        Delete tags for a report schedule.  # noqa: E501
        """
        pass

    def test_download_execution_pdf_report(self):
        """Test case for download_execution_pdf_report

        Download PDF report for given execution.  # noqa: E501
        """
        pass

    def test_generate_execution_pdf_report(self):
        """Test case for generate_execution_pdf_report

        Generate a PDF report for given execution.  # noqa: E501
        """
        pass

    def test_get_api_usage_report(self):
        """Test case for get_api_usage_report

        Gets the report of API usage metrics over a given time period. This API returns at the most 10000 results in the response to protect against the server running out of memory. Users might not hit this limit with the default report without any 'apiUsageReportGroupByParam' param but can hit this limit if the groupBy is by too granular like by 'client_name' or 'user_agent' only. Hence it is advisable to use startDate and endDate to 'limit' the scope of the report.  # noqa: E501
        """
        pass

    def test_get_audit_logs_summary_report(self):
        """Test case for get_audit_logs_summary_report

        Gets the audit log summary report.  # noqa: E501
        """
        pass

    def test_get_data_risk_report(self):
        """Test case for get_data_risk_report

        Get the masking data risk report.  # noqa: E501
        """
        pass

    def test_get_dataset_performance_analytics(self):
        """Test case for get_dataset_performance_analytics

        Get Dataset Performance analytics  # noqa: E501
        """
        pass

    def test_get_dsource_consumption_report(self):
        """Test case for get_dsource_consumption_report

        Gets the consumption report for virtualization engine dSources.  # noqa: E501
        """
        pass

    def test_get_dsource_usage_report(self):
        """Test case for get_dsource_usage_report

        Gets the usage report for virtualization engine dSources.  # noqa: E501
        """
        pass

    def test_get_engine_global_object_state_report(self):
        """Test case for get_engine_global_object_state_report

        Get the masking engine global object state report.  # noqa: E501
        """
        pass

    def test_get_engine_performance_analytics_report(self):
        """Test case for get_engine_performance_analytics_report

        Gets the performance analytics report for engines.  # noqa: E501
        """
        pass

    def test_get_masking_execution_metrics_report(self):
        """Test case for get_masking_execution_metrics_report

        Get the masking execution metrics report.  # noqa: E501
        """
        pass

    def test_get_product_info(self):
        """Test case for get_product_info

        Returns the DCT Product Information.  # noqa: E501
        """
        pass

    def test_get_reporting_schedule_by_id(self):
        """Test case for get_reporting_schedule_by_id

        Returns a report schedule by ID.  # noqa: E501
        """
        pass

    def test_get_reporting_schedule_tags(self):
        """Test case for get_reporting_schedule_tags

        Get tags for a report schedule.  # noqa: E501
        """
        pass

    def test_get_reporting_schedules(self):
        """Test case for get_reporting_schedules

        List all report schedules.  # noqa: E501
        """
        pass

    def test_get_storage_capacity_data(self):
        """Test case for get_storage_capacity_data

        Get engine storage capacity data.  # noqa: E501
        """
        pass

    def test_get_vdb_inventory_report(self):
        """Test case for get_vdb_inventory_report

        Gets the inventory report for virtualization engine VDBs.  # noqa: E501
        """
        pass

    def test_get_virtualization_storage_summary_report(self):
        """Test case for get_virtualization_storage_summary_report

        Gets the storage summary report for virtualization engines.  # noqa: E501
        """
        pass

    def test_search_data_risk_report(self):
        """Test case for search_data_risk_report

        Search the masking data risk report.  # noqa: E501
        """
        pass

    def test_search_dataset_performance_analytics_summary(self):
        """Test case for search_dataset_performance_analytics_summary

        Search Dataset Performance analytics summary  # noqa: E501
        """
        pass

    def test_search_dsource_consumption_report(self):
        """Test case for search_dsource_consumption_report

        Search the consumption report for virtualization engine DSources.  # noqa: E501
        """
        pass

    def test_search_dsource_usage_report(self):
        """Test case for search_dsource_usage_report

        Search the usage report for virtualization engine dSources.  # noqa: E501
        """
        pass

    def test_search_engine_global_object_state_report(self):
        """Test case for search_engine_global_object_state_report

        Search the masking engine global object state report.  # noqa: E501
        """
        pass

    def test_search_engine_performance_analytic_trends(self):
        """Test case for search_engine_performance_analytic_trends

        Search the performance analytic trend data for engines.  # noqa: E501
        """
        pass

    def test_search_engine_performance_analytics_report(self):
        """Test case for search_engine_performance_analytics_report

        Search the performance analytic report for engines.  # noqa: E501
        """
        pass

    def test_search_masking_execution_metrics_report(self):
        """Test case for search_masking_execution_metrics_report

        Search the Masking execution metrics report.  # noqa: E501
        """
        pass

    def test_search_reporting_schedules(self):
        """Test case for search_reporting_schedules

        Search for report schedules.  # noqa: E501
        """
        pass

    def test_search_storage_capacity_data(self):
        """Test case for search_storage_capacity_data

        Search engine storage capacity data.  # noqa: E501
        """
        pass

    def test_search_storage_savings_summary_report(self):
        """Test case for search_storage_savings_summary_report

        Search the saving storage summary report for virtualization engines.  # noqa: E501
        """
        pass

    def test_search_vdb_inventory_report(self):
        """Test case for search_vdb_inventory_report

        Search the inventory report for virtualization engine VDBs.  # noqa: E501
        """
        pass

    def test_search_virtualization_storage_summary_report(self):
        """Test case for search_virtualization_storage_summary_report

        Search the storage summary report for virtualization engines.  # noqa: E501
        """
        pass

    def test_update_reporting_schedule(self):
        """Test case for update_reporting_schedule

        Update a reporting schedule by ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
