"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.cloud_accounts_api import CloudAccountsApi  # noqa: E501


class TestCloudAccountsApi(unittest.TestCase):
    """CloudAccountsApi unit test stubs"""

    def setUp(self):
        self.api = CloudAccountsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_cloud_account(self):
        """Test case for create_cloud_account

        Create a new Cloud Account  # noqa: E501
        """
        pass

    def test_create_cloud_account_tags(self):
        """Test case for create_cloud_account_tags

        Create tags for a Cloud Account.  # noqa: E501
        """
        pass

    def test_delete_cloud_account(self):
        """Test case for delete_cloud_account

        """
        pass

    def test_delete_cloud_account_tags(self):
        """Test case for delete_cloud_account_tags

        Delete tags for a Cloud Account.  # noqa: E501
        """
        pass

    def test_get_cloud_account_metadata(self):
        """Test case for get_cloud_account_metadata

        Cloud Account metadata  # noqa: E501
        """
        pass

    def test_get_cloud_account_tags(self):
        """Test case for get_cloud_account_tags

        Get tags for a Cloud Account.  # noqa: E501
        """
        pass

    def test_get_cloud_accounts(self):
        """Test case for get_cloud_accounts

        List all Cloud Accounts.  # noqa: E501
        """
        pass

    def test_search_cloud_accounts(self):
        """Test case for search_cloud_accounts

        Search for Cloud Accounts.  # noqa: E501
        """
        pass

    def test_update_cloud_account(self):
        """Test case for update_cloud_account

        Update an existing Cloud Account  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
