"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.held_space_api import HeldSpaceApi  # noqa: E501


class TestHeldSpaceApi(unittest.TestCase):
    """HeldSpaceApi unit test stubs"""

    def setUp(self):
        self.api = HeldSpaceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_heldspace_by_id(self):
        """Test case for delete_heldspace_by_id

        Delete a HeldSpace.  # noqa: E501
        """
        pass

    def test_get_heldspace_deletion_dependencies(self):
        """Test case for get_heldspace_deletion_dependencies

        Get heldspace deletion dependencies.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
