"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.cdb_d_sources_api import CDBDSourcesApi  # noqa: E501


class TestCDBDSourcesApi(unittest.TestCase):
    """CDBDSourcesApi unit test stubs"""

    def setUp(self):
        self.api = CDBDSourcesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_attach_cdb_dsource(self):
        """Test case for attach_cdb_dsource

        Attaches an Oracle CDB to an Oracle database.  # noqa: E501
        """
        pass

    def test_create_cdb_dsource_tags(self):
        """Test case for create_cdb_dsource_tags

        Create tags for a CDB DSource.  # noqa: E501
        """
        pass

    def test_delete_cdb_dsource(self):
        """Test case for delete_cdb_dsource

        Delete a CDB dSource.  # noqa: E501
        """
        pass

    def test_delete_cdb_dsource_tags(self):
        """Test case for delete_cdb_dsource_tags

        Delete tags for a CDB DSource.  # noqa: E501
        """
        pass

    def test_detach_cdb_dsource(self):
        """Test case for detach_cdb_dsource

        Detaches an Oracle CDB from an Oracle database.  # noqa: E501
        """
        pass

    def test_disable_cdb_dsource(self):
        """Test case for disable_cdb_dsource

        Disable a CDB dSource.  # noqa: E501
        """
        pass

    def test_enable_cdb_dsource(self):
        """Test case for enable_cdb_dsource

        Enable a CDB dSource.  # noqa: E501
        """
        pass

    def test_get_cdb_dsource_by_id(self):
        """Test case for get_cdb_dsource_by_id

        Get a CDB dSource by ID (Oracle only).  # noqa: E501
        """
        pass

    def test_get_cdb_dsources(self):
        """Test case for get_cdb_dsources

        List all CDB dSources (Oracle only).  # noqa: E501
        """
        pass

    def test_get_tags_cdb_dsource(self):
        """Test case for get_tags_cdb_dsource

        Get tags for a CDB DSource.  # noqa: E501
        """
        pass

    def test_search_cdb_dsources(self):
        """Test case for search_cdb_dsources

        Search for CDB dSources (Oracle only).  # noqa: E501
        """
        pass

    def test_update_cdb_dsource(self):
        """Test case for update_cdb_dsource

        Update a CDB DSource.  # noqa: E501
        """
        pass

    def test_upgrade_cdb_dsource(self):
        """Test case for upgrade_cdb_dsource

        Upgrade Oracle CDB dSource  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
