"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.file_mapping_api import FileMappingApi  # noqa: E501


class TestFileMappingApi(unittest.TestCase):
    """FileMappingApi unit test stubs"""

    def setUp(self):
        self.api = FileMappingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_file_mapping_by_bookmark(self):
        """Test case for get_file_mapping_by_bookmark

        Validate file mapping using bookmark  # noqa: E501
        """
        pass

    def test_get_file_mapping_by_location(self):
        """Test case for get_file_mapping_by_location

        Validate file mapping using location  # noqa: E501
        """
        pass

    def test_get_file_mapping_by_snapshot(self):
        """Test case for get_file_mapping_by_snapshot

        Validate file mapping using snapshots  # noqa: E501
        """
        pass

    def test_get_file_mapping_by_timestamp(self):
        """Test case for get_file_mapping_by_timestamp

        Validate file mapping using timestamp  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
