"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.engine_historical_storage_summary import EngineHistoricalStorageSummary
globals()['EngineHistoricalStorageSummary'] = EngineHistoricalStorageSummary
from delphix.api.gateway.model.historical_storage_summary import HistoricalStorageSummary


class TestHistoricalStorageSummary(unittest.TestCase):
    """HistoricalStorageSummary unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testHistoricalStorageSummary(self):
        """Test HistoricalStorageSummary"""
        # FIXME: construct object with mandatory attributes with example values
        # model = HistoricalStorageSummary()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
