"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.hook_templates_api import HookTemplatesApi  # noqa: E501


class TestHookTemplatesApi(unittest.TestCase):
    """HookTemplatesApi unit test stubs"""

    def setUp(self):
        self.api = HookTemplatesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_hook_template(self):
        """Test case for create_hook_template

        Create a Hook Template.  # noqa: E501
        """
        pass

    def test_create_hook_template_tags(self):
        """Test case for create_hook_template_tags

        Create tags for a Hook Template.  # noqa: E501
        """
        pass

    def test_delete_hook_template(self):
        """Test case for delete_hook_template

        Delete a Hook Template.  # noqa: E501
        """
        pass

    def test_delete_hook_template_tags(self):
        """Test case for delete_hook_template_tags

        Delete tags for a Hook Template.  # noqa: E501
        """
        pass

    def test_get_hook_template_by_id(self):
        """Test case for get_hook_template_by_id

        Fetch Hook Template by ID  # noqa: E501
        """
        pass

    def test_get_hook_template_tags(self):
        """Test case for get_hook_template_tags

        Get tags for a Hook Template.  # noqa: E501
        """
        pass

    def test_list_hook_templates(self):
        """Test case for list_hook_templates

        Fetch a list of all hook templates  # noqa: E501
        """
        pass

    def test_search_hook_templates(self):
        """Test case for search_hook_templates

        Search Hook Templates.  # noqa: E501
        """
        pass

    def test_update_hook_template(self):
        """Test case for update_hook_template

        Update a Hook Template.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
