"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.d_source_hooks import DSourceHooks
from delphix.api.gateway.model.name_value_pair import NameValuePair
from delphix.api.gateway.model.oracle_logsync_mode_type_enum import OracleLogsyncModeTypeEnum
globals()['DSourceHooks'] = DSourceHooks
globals()['NameValuePair'] = NameValuePair
globals()['OracleLogsyncModeTypeEnum'] = OracleLogsyncModeTypeEnum
from delphix.api.gateway.model.update_oracle_dsource_parameters import UpdateOracleDsourceParameters


class TestUpdateOracleDsourceParameters(unittest.TestCase):
    """UpdateOracleDsourceParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUpdateOracleDsourceParameters(self):
        """Test UpdateOracleDsourceParameters"""
        # FIXME: construct object with mandatory attributes with example values
        # model = UpdateOracleDsourceParameters()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
