"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.executions_api import ExecutionsApi  # noqa: E501


class TestExecutionsApi(unittest.TestCase):
    """ExecutionsApi unit test stubs"""

    def setUp(self):
        self.api = ExecutionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_execution(self):
        """Test case for cancel_execution

        Cancel an Execution.  # noqa: E501
        """
        pass

    def test_cleanup_execution(self):
        """Test case for cleanup_execution

        Cleanup an Execution (Hyperscale only).  # noqa: E501
        """
        pass

    def test_get_discovery_results(self):
        """Test case for get_discovery_results

        Retrieve the list of discovery results for a masking execution.  # noqa: E501
        """
        pass

    def test_get_execution_by_id(self):
        """Test case for get_execution_by_id

        Retrieve an Execution by ID.  # noqa: E501
        """
        pass

    def test_get_execution_component_by_id(self):
        """Test case for get_execution_component_by_id

        Get an execution component by ID.  # noqa: E501
        """
        pass

    def test_get_execution_component_log(self):
        """Test case for get_execution_component_log

        Get an execution component log.  # noqa: E501
        """
        pass

    def test_get_execution_components(self):
        """Test case for get_execution_components

        Get execution components for an execution.  # noqa: E501
        """
        pass

    def test_get_execution_events(self):
        """Test case for get_execution_events

        Retrieve the list of events for a masking execution.  # noqa: E501
        """
        pass

    def test_get_execution_log(self):
        """Test case for get_execution_log

        Retrieve the masking execution log.  # noqa: E501
        """
        pass

    def test_get_executions(self):
        """Test case for get_executions

        Retrieve the list of masking executions.  # noqa: E501
        """
        pass

    def test_restart_execution(self):
        """Test case for restart_execution

        Restart an Execution (Hyperscale only).  # noqa: E501
        """
        pass

    def test_search_discovery_results(self):
        """Test case for search_discovery_results

        Search discovery results associated with execution of a discovery job  # noqa: E501
        """
        pass

    def test_search_execution_components(self):
        """Test case for search_execution_components

        Search execution components for an execution.  # noqa: E501
        """
        pass

    def test_search_execution_events(self):
        """Test case for search_execution_events

        Search masking executions events.  # noqa: E501
        """
        pass

    def test_search_executions(self):
        """Test case for search_executions

        Search masking executions.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
