"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.paas_instance_api import PaasInstanceApi  # noqa: E501


class TestPaasInstanceApi(unittest.TestCase):
    """PaasInstanceApi unit test stubs"""

    def setUp(self):
        self.api = PaasInstanceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_bookmarks_by_paas_instance(self):
        """Test case for get_bookmarks_by_paas_instance

        List Bookmarks compatible with this PaaS Instance.  # noqa: E501
        """
        pass

    def test_search_bookmarks_by_paas_instance(self):
        """Test case for search_bookmarks_by_paas_instance

        Search Bookmarks compatible with this PaaS Instance.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
