"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.masking_plugins_api import MaskingPluginsApi  # noqa: E501


class TestMaskingPluginsApi(unittest.TestCase):
    """MaskingPluginsApi unit test stubs"""

    def setUp(self):
        self.api = MaskingPluginsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_masking_plugin(self):
        """Test case for create_masking_plugin

        Install a masking plugin.  # noqa: E501
        """
        pass

    def test_create_masking_plugin_tags(self):
        """Test case for create_masking_plugin_tags

        Create tags for a masking plugin.  # noqa: E501
        """
        pass

    def test_delete_masking_plugin_tags(self):
        """Test case for delete_masking_plugin_tags

        Delete tags for a masking plugin.  # noqa: E501
        """
        pass

    def test_get_algorithm_framework_by_id(self):
        """Test case for get_algorithm_framework_by_id

        Get an algorithm framework by ID or name.  # noqa: E501
        """
        pass

    def test_get_masking_plugin_by_id(self):
        """Test case for get_masking_plugin_by_id

        Get a masking plugin by ID or name.  # noqa: E501
        """
        pass

    def test_get_masking_plugin_tags(self):
        """Test case for get_masking_plugin_tags

        Get tags for a masking plugin.  # noqa: E501
        """
        pass

    def test_get_masking_plugins(self):
        """Test case for get_masking_plugins

        Retrieve the list of masking plugins.  # noqa: E501
        """
        pass

    def test_search_masking_plugins(self):
        """Test case for search_masking_plugins

        Search for masking plugins.  # noqa: E501
        """
        pass

    def test_update_masking_plugin(self):
        """Test case for update_masking_plugin

        Update a Masking Plugin.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
