"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.enable_vdb_parameters import EnableVDBParameters
from delphix.api.gateway.model.vdb_enable_parameters_mapping_all_of import VDBEnableParametersMappingAllOf
globals()['EnableVDBParameters'] = EnableVDBParameters
globals()['VDBEnableParametersMappingAllOf'] = VDBEnableParametersMappingAllOf
from delphix.api.gateway.model.vdb_enable_parameters_mapping import VDBEnableParametersMapping


class TestVDBEnableParametersMapping(unittest.TestCase):
    """VDBEnableParametersMapping unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testVDBEnableParametersMapping(self):
        """Test VDBEnableParametersMapping"""
        # FIXME: construct object with mandatory attributes with example values
        # model = VDBEnableParametersMapping()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
